@@ -1,23 +1,22 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
-  
+  Copyright (C) 2001-2020 Aymeric MOIZARD amoizard@antisip.com
+
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.
-  
+
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.
-  
+
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-
 #ifndef _OSIP_CONTENT_DISPOSITION_H_
 #define _OSIP_CONTENT_DISPOSITION_H_
 
@@ -38,42 +37,40 @@
  * Structure for Content-Disposition headers.
  * @var osip_content_disposition_t
  */
-  typedef osip_call_info_t osip_content_disposition_t;
+typedef osip_call_info_t osip_content_disposition_t;
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
 /**
  * Allocate a Content-Disposition element.
  * @param header The element to work on.
  */
-#define osip_content_disposition_init(header)      osip_call_info_init(header)
+#define osip_content_disposition_init(header) osip_call_info_init(header)
 /**
  * Free a Content-Disposition element.
  * @param header The element to work on.
  */
-#define osip_content_disposition_free(header)      osip_call_info_free(header)
+#define osip_content_disposition_free(header) osip_call_info_free(header)
 /**
  * Parse a Content-Disposition element.
  * @param header The element to work on.
  * @param hvalue The string to parse.
  */
-  int osip_content_disposition_parse (osip_content_disposition_t * header,
-				 const char *hvalue);
+int osip_content_disposition_parse(osip_content_disposition_t *header, const char *hvalue);
 /**
  * Get a string representation of a Content-Disposition element.
  * @param header The element to work on.
  * @param dest A pointer on the new allocated string.
  */
-#define osip_content_disposition_to_str(header,dest)   osip_call_info_to_str(header,dest)
+#define osip_content_disposition_to_str(header, dest) osip_call_info_to_str(header, dest)
 /**
  * Clone a Content-Disposition element.
  * @param header The element to work on.
  * @param dest A pointer on the copy of the element.
  */
-#define osip_content_disposition_clone(header, dest)  osip_call_info_clone(header, dest)
+#define osip_content_disposition_clone osip_call_info_clone
 
 /* type is of: "render" | "session" | "icon" | "alert" */
 /**
@@ -86,8 +83,7 @@ extern "C"
  * Get the type from a Content-Disposition header.
  * @param header The element to work on.
  */
-#define osip_content_disposition_get_type(header)    osip_call_info_get_uri(header)
-
+#define osip_content_disposition_get_type(header) osip_call_info_get_uri(header)
 
 #ifdef __cplusplus
 }
